# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .knowledge_base_response import KnowledgeBaseResponse

__all__ = ["KnowledgeBaseListResponse"]

KnowledgeBaseListResponse: TypeAlias = List[KnowledgeBaseResponse]
